@@ -1,9 +1,9 @@
 test_that("arc_select(): CRS is respected", {
-  url <- "https://services1.arcgis.com/UWYHeuuJISiGmgXx/arcgis/rest/services/Police_District/FeatureServer/0"
+  furl <- "https://services.arcgis.com/P3ePLMYs2RVChkJx/arcgis/rest/services/USA_Counties_Generalized_Boundaries/FeatureServer/0"
 
   epsg_code <- 2804
 
-  flayer <- arc_open(url)
+  flayer <- arc_open(furl)
 
   res <- arc_select(flayer, crs = epsg_code, n_max = 1)
 
@@ -12,5 +12,3 @@ test_that("arc_select(): CRS is respected", {
     sf::st_crs(epsg_code)
   )
 })
-
-
